@@ -8,11 +8,25 @@ package HTML::Element::traverse;
 use warnings;
 use strict;
 
-our $VERSION = '5.04';
+our $VERSION = '5.05'; # VERSION from OurPkgVersion
 
 use HTML::Element ();
 1;
 
+__END__
+
+=pod
+
+=head1 NAME
+
+HTML::Element::traverse - discussion of HTML::Element's traverse method
+
+=head1 VERSION
+
+This document describes version 5.05 of
+HTML::Element::traverse, released April 26, 2017
+as part of L<HTML-Tree|HTML::Tree>.
+
 =head1 SYNOPSIS
 
   # $element->traverse is unnecessary and obscure.
@@ -318,6 +332,41 @@ or you can just do it with flags:
 
 L<HTML::Element>
 
+=head1 AUTHOR
+
+Current maintainers:
+
+=over
+
+=item * Christopher J. Madsen S<C<< <perl AT cjmweb.net> >>>
+
+=item * Jeff Fearn S<C<< <jfearn AT cpan.org> >>>
+
+=back
+
+Original HTML-Tree author:
+
+=over
+
+=item * Gisle Aas
+
+=back
+
+Former maintainers:
+
+=over
+
+=item * Sean M. Burke
+
+=item * Andy Lester
+
+=item * Pete Krawczyk S<C<< <petek AT cpan.org> >>>
+
+=back
+
+You can follow or contribute to HTML-Tree's development at
+L<< https://github.com/kentfredric/HTML-Tree >>.
+
 =head1 COPYRIGHT
 
 Copyright 2000,2001 Sean M. Burke
