@@ -7,7 +7,7 @@ use strict;
 use integer;    # vroom vroom!
 use Carp ();
 
-our $VERSION = '5.04';
+our $VERSION = '5.05'; # VERSION from OurPkgVersion
 
 #---------------------------------------------------------------------------
 # Make a 'DEBUG' constant...
@@ -1672,6 +1672,20 @@ sub disembowel { $_[0]->guts(1) }
 #--------------------------------------------------------------------------
 1;
 
+__END__
+
+=pod
+
+=head1 NAME
+
+HTML::TreeBuilder - Parser that builds a HTML syntax tree
+
+=head1 VERSION
+
+This document describes version 5.05 of
+HTML::TreeBuilder, released April 26, 2017
+as part of L<HTML-Tree|HTML::Tree>.
+
 =head1 SYNOPSIS
 
   use HTML::TreeBuilder 5 -weak; # Ensure weak references in use
@@ -1716,6 +1730,142 @@ C<< $tree->delete() >> to erase the contents of the tree from memory
 when you're done with the tree.  This is not normally required anymore.
 See L<HTML::Element/"Weak References"> for details.
 
+=head1 ATTRIBUTES
+
+Most of the following attributes native to HTML::TreeBuilder control how
+parsing takes place; they should be set I<before> you try parsing into
+the given object.  You can set the attributes by passing a TRUE or
+FALSE value as argument.  E.g., C<< $root->implicit_tags >> returns
+the current setting for the C<implicit_tags> option,
+C<< $root->implicit_tags(1) >> turns that option on,
+and C<< $root->implicit_tags(0) >> turns it off.
+
+=head2 implicit_tags
+
+Setting this attribute to true will instruct the parser to try to
+deduce implicit elements and implicit end tags.  If it is false you
+get a parse tree that just reflects the text as it stands, which is
+unlikely to be useful for anything but quick and dirty parsing.
+(In fact, I'd be curious to hear from anyone who finds it useful to
+have C<implicit_tags> set to false.)
+Default is true.
+
+Implicit elements have the L<HTML::Element/implicit> attribute set.
+
+=head2 implicit_body_p_tag
+
+This controls an aspect of implicit element behavior, if C<implicit_tags>
+is on:  If a text element (PCDATA) or a phrasal element (such as
+C<< <em> >>) is to be inserted under C<< <body> >>, two things
+can happen: if C<implicit_body_p_tag> is true, it's placed under a new,
+implicit C<< <p> >> tag.  (Past DTDs suggested this was the only
+correct behavior, and this is how past versions of this module
+behaved.)  But if C<implicit_body_p_tag> is false, nothing is implicated
+-- the PCDATA or phrasal element is simply placed under
+C<< <body> >>.  Default is false.
+
+=head2 no_expand_entities
+
+This attribute controls whether entities are decoded during the initial
+parse of the source. Enable this if you don't want entities decoded to
+their character value. e.g. '&amp;' is decoded to '&' by default, but
+will be unchanged if this is enabled.
+Default is false (entities will be decoded.)
+
+=head2 ignore_unknown
+
+This attribute controls whether unknown tags should be represented as
+elements in the parse tree, or whether they should be ignored.
+Default is true (to ignore unknown tags.)
+
+=head2 ignore_text
+
+Do not represent the text content of elements.  This saves space if
+all you want is to examine the structure of the document.  Default is
+false.
+
+=head2 ignore_ignorable_whitespace
+
+If set to true, TreeBuilder will try to avoid
+creating ignorable whitespace text nodes in the tree.  Default is
+true.  (In fact, I'd be interested in hearing if there's ever a case
+where you need this off, or where leaving it on leads to incorrect
+behavior.)
+
+=head2 no_space_compacting
+
+This determines whether TreeBuilder compacts all whitespace strings
+in the document (well, outside of PRE or TEXTAREA elements), or
+leaves them alone.  Normally (default, value of 0), each string of
+contiguous whitespace in the document is turned into a single space.
+But that's not done if C<no_space_compacting> is set to 1.
+
+Setting C<no_space_compacting> to 1 might be useful if you want
+to read in a tree just to make some minor changes to it before
+writing it back out.
+
+This method is experimental.  If you use it, be sure to report
+any problems you might have with it.
+
+=head2 p_strict
+
+If set to true (and it defaults to false), TreeBuilder will take a
+narrower than normal view of what can be under a C<< <p> >> element; if it sees
+a non-phrasal element about to be inserted under a C<< <p> >>, it will
+close that C<< <p> >>.  Otherwise it will close C<< <p> >> elements only for
+other C<< <p> >>'s, headings, and C<< <form> >> (although the latter may be
+removed in future versions).
+
+For example, when going thru this snippet of code,
+
+  <p>stuff
+  <ul>
+
+TreeBuilder will normally (with C<p_strict> false) put the C<< <ul> >> element
+under the C<< <p> >> element.  However, with C<p_strict> set to true, it will
+close the C<< <p> >> first.
+
+In theory, there should be strictness options like this for other/all
+elements besides just C<< <p> >>; but I treat this as a special case simply
+because of the fact that C<< <p> >> occurs so frequently and its end-tag is
+omitted so often; and also because application of strictness rules
+at parse-time across all elements often makes tiny errors in HTML
+coding produce drastically bad parse-trees, in my experience.
+
+If you find that you wish you had an option like this to enforce
+content-models on all elements, then I suggest that what you want is
+content-model checking as a stage after TreeBuilder has finished
+parsing.
+
+=head2 store_comments
+
+This determines whether TreeBuilder will normally store comments found
+while parsing content into C<$root>.  Currently, this is off by default.
+
+=head2 store_declarations
+
+This determines whether TreeBuilder will normally store markup
+declarations found while parsing content into C<$root>.  This is on
+by default.
+
+=head2 store_pis
+
+This determines whether TreeBuilder will normally store processing
+instructions found while parsing content into C<$root> -- assuming a
+recent version of HTML::Parser (old versions won't parse PIs
+correctly).  Currently, this is off (false) by default.
+
+It is somewhat of a known bug (to be fixed one of these days, if
+anyone needs it?) that PIs in the preamble (before the C<< <html> >>
+start-tag) end up actually I<under> the C<< <html> >> element.
+
+=head2 warn
+
+This determines whether syntax errors during parsing should generate
+warnings, emitted via Perl's C<warn> function.
+
+This is off (false) by default.
+
 =head1 METHODS
 
 Objects of this class inherit the methods of both HTML::Parser and
@@ -1727,16 +1877,6 @@ HTML::Element documentation, and also skim the HTML::Parser
 documentation -- probably only its parse and parse_file methods are of
 interest.
 
-=head1 ATTRIBUTES
-
-Most of the following attributes native to HTML::TreeBuilder control how
-parsing takes place; they should be set I<before> you try parsing into
-the given object.  You can set the attributes by passing a TRUE or
-FALSE value as argument.  E.g., C<< $root->implicit_tags >> returns
-the current setting for the C<implicit_tags> option,
-C<< $root->implicit_tags(1) >> turns that option on,
-and C<< $root->implicit_tags(0) >> turns it off.
-
 =head2 new_from_file
 
   $root = HTML::TreeBuilder->new_from_file($filename_or_filehandle);
@@ -1924,132 +2064,6 @@ are returned.  Usually when you want the guts from a tree, you're just
 going to toss out the rest of the tree anyway, so this saves you the
 bother.  (Remember, "disembowel" means "remove the guts from".)
 
-=head2 implicit_tags
-
-Setting this attribute to true will instruct the parser to try to
-deduce implicit elements and implicit end tags.  If it is false you
-get a parse tree that just reflects the text as it stands, which is
-unlikely to be useful for anything but quick and dirty parsing.
-(In fact, I'd be curious to hear from anyone who finds it useful to
-have C<implicit_tags> set to false.)
-Default is true.
-
-Implicit elements have the L<HTML::Element/implicit> attribute set.
-
-=head2 implicit_body_p_tag
-
-This controls an aspect of implicit element behavior, if C<implicit_tags>
-is on:  If a text element (PCDATA) or a phrasal element (such as
-C<< <em> >>) is to be inserted under C<< <body> >>, two things
-can happen: if C<implicit_body_p_tag> is true, it's placed under a new,
-implicit C<< <p> >> tag.  (Past DTDs suggested this was the only
-correct behavior, and this is how past versions of this module
-behaved.)  But if C<implicit_body_p_tag> is false, nothing is implicated
--- the PCDATA or phrasal element is simply placed under
-C<< <body> >>.  Default is false.
-
-=head2 no_expand_entities
-
-This attribute controls whether entities are decoded during the initial
-parse of the source. Enable this if you don't want entities decoded to
-their character value. e.g. '&amp;' is decoded to '&' by default, but
-will be unchanged if this is enabled.
-Default is false (entities will be decoded.)
-
-=head2 ignore_unknown
-
-This attribute controls whether unknown tags should be represented as
-elements in the parse tree, or whether they should be ignored.
-Default is true (to ignore unknown tags.)
-
-=head2 ignore_text
-
-Do not represent the text content of elements.  This saves space if
-all you want is to examine the structure of the document.  Default is
-false.
-
-=head2 ignore_ignorable_whitespace
-
-If set to true, TreeBuilder will try to avoid
-creating ignorable whitespace text nodes in the tree.  Default is
-true.  (In fact, I'd be interested in hearing if there's ever a case
-where you need this off, or where leaving it on leads to incorrect
-behavior.)
-
-=head2 no_space_compacting
-
-This determines whether TreeBuilder compacts all whitespace strings
-in the document (well, outside of PRE or TEXTAREA elements), or
-leaves them alone.  Normally (default, value of 0), each string of
-contiguous whitespace in the document is turned into a single space.
-But that's not done if C<no_space_compacting> is set to 1.
-
-Setting C<no_space_compacting> to 1 might be useful if you want
-to read in a tree just to make some minor changes to it before
-writing it back out.
-
-This method is experimental.  If you use it, be sure to report
-any problems you might have with it.
-
-=head2 p_strict
-
-If set to true (and it defaults to false), TreeBuilder will take a
-narrower than normal view of what can be under a C<< <p> >> element; if it sees
-a non-phrasal element about to be inserted under a C<< <p> >>, it will
-close that C<< <p> >>.  Otherwise it will close C<< <p> >> elements only for
-other C<< <p> >>'s, headings, and C<< <form> >> (although the latter may be
-removed in future versions).
-
-For example, when going thru this snippet of code,
-
-  <p>stuff
-  <ul>
-
-TreeBuilder will normally (with C<p_strict> false) put the C<< <ul> >> element
-under the C<< <p> >> element.  However, with C<p_strict> set to true, it will
-close the C<< <p> >> first.
-
-In theory, there should be strictness options like this for other/all
-elements besides just C<< <p> >>; but I treat this as a special case simply
-because of the fact that C<< <p> >> occurs so frequently and its end-tag is
-omitted so often; and also because application of strictness rules
-at parse-time across all elements often makes tiny errors in HTML
-coding produce drastically bad parse-trees, in my experience.
-
-If you find that you wish you had an option like this to enforce
-content-models on all elements, then I suggest that what you want is
-content-model checking as a stage after TreeBuilder has finished
-parsing.
-
-=head2 store_comments
-
-This determines whether TreeBuilder will normally store comments found
-while parsing content into C<$root>.  Currently, this is off by default.
-
-=head2 store_declarations
-
-This determines whether TreeBuilder will normally store markup
-declarations found while parsing content into C<$root>.  This is on
-by default.
-
-=head2 store_pis
-
-This determines whether TreeBuilder will normally store processing
-instructions found while parsing content into C<$root> -- assuming a
-recent version of HTML::Parser (old versions won't parse PIs
-correctly).  Currently, this is off (false) by default.
-
-It is somewhat of a known bug (to be fixed one of these days, if
-anyone needs it?) that PIs in the preamble (before the C<< <html> >>
-start-tag) end up actually I<under> the C<< <html> >> element.
-
-=head2 warn
-
-This determines whether syntax errors during parsing should generate
-warnings, emitted via Perl's C<warn> function.
-
-This is off (false) by default.
-
 =head1 INTERNAL METHODS
 
 You should not need to call any of the following methods directly.
@@ -2063,12 +2077,6 @@ defaults to HTML::Element, but can be overridden by subclassing or esoteric
 means best left to those will will read the source and then not complain when
 those esoteric means change.  (Just subclass.)
 
-=head2 DEBUG
-
-Are we in Debug mode?  This is a constant subroutine, to allow
-compile-time optimizations.  To control debug mode, set
-C<$HTML::TreeBuilder::DEBUG> I<before> loading HTML::TreeBuilder.
-
 =head2 comment
 
 Accept a "here's a comment" signal from HTML::Parser.
@@ -2125,6 +2133,14 @@ Wrapper for CORE::warn
 
 TODO: why not just use carp?
 
+=head1 SUBROUTINES
+
+=head2 DEBUG
+
+Are we in Debug mode?  This is a constant subroutine, to allow
+compile-time optimizations.  To control debug mode, set
+C<$HTML::TreeBuilder::DEBUG> I<before> loading HTML::TreeBuilder.
+
 =head1 HTML AND ITS DISCONTENTS
 
 HTML is rather harder to parse than people who write it generally
@@ -2230,4 +2246,52 @@ L<XML::Element> trees: L<HTML::DOMbo>.
 
 For opening a HTML file with automatic charset detection: L<IO::HTML>.
 
+=head1 AUTHOR
+
+Current maintainers:
+
+=over
+
+=item * Christopher J. Madsen S<C<< <perl AT cjmweb.net> >>>
+
+=item * Jeff Fearn S<C<< <jfearn AT cpan.org> >>>
+
+=back
+
+Original HTML-Tree author:
+
+=over
+
+=item * Gisle Aas
+
+=back
+
+Former maintainers:
+
+=over
+
+=item * Sean M. Burke
+
+=item * Andy Lester
+
+=item * Pete Krawczyk S<C<< <petek AT cpan.org> >>>
+
+=back
+
+You can follow or contribute to HTML-Tree's development at
+L<< https://github.com/kentfredric/HTML-Tree >>.
+
+=head1 COPYRIGHT AND LICENSE
+
+Copyright 1995-1998 Gisle Aas, 1999-2004 Sean M. Burke,
+2005 Andy Lester, 2006 Pete Krawczyk, 2010 Jeff Fearn,
+2012 Christopher J. Madsen.
+
+This library is free software; you can redistribute it and/or
+modify it under the same terms as Perl itself.
+
+The programs in this library are distributed in the hope that they
+will be useful, but without any warranty; without even the implied
+warranty of merchantability or fitness for a particular purpose.
+
 =cut
